package com.yanzuoguang.util.helper;

import com.yanzuoguang.util.exception.CodeException;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.RandomAccessFile;

/**
 * 登录相关函数
 */
public class FileHelper {

    /**
     * 获取登录标记
     *
     * @param file     文件路径
     * @param encoding 文件编码
     * @return 读取的内容
     */
    public static String readFile(File file, String encoding) {
        //检查此路径名的文件是否是一个目录(文件夹)
        if (file.isDirectory()) {
            return StringHelper.EMPTY;
        }
        if (!file.exists()) {
            return StringHelper.EMPTY;
        }
        try {
            InputStream inputStream = new FileInputStream(file);
            return readFile(inputStream, encoding);
        } catch (CodeException e) {
            throw e;
        } catch (Exception e) {
            throw new CodeException(e);
        }
    }

    /**
     * 读取文件内容
     *
     * @param inputStream 文件流
     * @param encoding    文件编码
     * @return 文件内容的结果
     */
    public static String readFile(InputStream inputStream, String encoding) {
        if (inputStream == null) {
            return StringHelper.EMPTY;
        }
        StringBuilder sb = new StringBuilder();
        try {
            try {
                InputStreamReader inputStreamReader = new InputStreamReader(inputStream, encoding);
                BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
                String line;
                //分行读取
                while ((line = bufferedReader.readLine()) != null) {
                    if (sb.length() > 0) {
                        sb.append("\n");
                    }
                    sb.append(line);
                }
            } finally {
                inputStream.close();//关闭输入流
            }
        } catch (CodeException e) {
            throw e;
        } catch (Exception e) {
            throw new CodeException(e);
        }
        return sb.toString();
    }

    /**
     * 写入文件内容
     *
     * @param file     文件路径
     * @param content  文件内容
     * @param encoding 文件编码
     */
    public static void writeFile(File file, String content, String encoding) {
        try {
            // 删除文件
            if (file.exists()) {
                file.delete();
            }
            if (file.exists()) {
                throw new CodeException("文件删除失败");
            }
            // 创建文件
            file.getParentFile().mkdirs();

            file.createNewFile();
            // 写入文件
            RandomAccessFile raf = new RandomAccessFile(file, "rwd");
            raf.seek(file.length());
            raf.write(content.getBytes(encoding));
            raf.close();
        } catch (CodeException e) {
            throw e;
        } catch (Exception e) {
            throw new CodeException(e);
        }
    }
}
