package com.yanzuoguang.cloud.helper;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.net.URL;
import java.net.URLConnection;

/**
 * HTTP文件
 */
public class HttpFileHelper {
    /**
     * 下载文件
     *
     * @param serverFileName 下载的服务器文件路径
     * @param localFileName  保存的文件路径
     * @throws IOException
     */
    public static void downToLocal(String serverFileName, String localFileName) throws IOException {
        int byteRead;
        URL url = new URL(serverFileName);
        URLConnection conn = url.openConnection();
        InputStream inStream = conn.getInputStream();
        try {
            FileOutputStream outputStream = new FileOutputStream(localFileName);
            try {
                byte[] buffer = new byte[1204];
                while ((byteRead = inStream.read(buffer)) != -1) {
                    outputStream.write(buffer, 0, byteRead);
                }
            } finally {
                outputStream.close();
            }
        } finally {
            inStream.close();
        }
    }


    /**
     * 下载文件
     *
     * @param serverFilePath 下载文件来源路径
     * @param saveFileName   文件保存名称
     * @param response       输出对象
     * @throws IOException 异常信息
     */
    public static void localToDown(String serverFilePath, String saveFileName, HttpServletResponse response) throws IOException {
        //获取文件的长度
        File file = new File(serverFilePath);
        //设置文件输出类型
        response.setContentType("application/octet-stream");
        // 设置下载的文件名
        response.setHeader("Content-disposition", "attachment; filename=" + new String(saveFileName.getBytes("utf-8"), "UTF-8"));
        //设置输出长度
        response.setHeader("Content-Length", String.valueOf(file.length()));
        ServletOutputStream bos = response.getOutputStream();
        // 获取输入流
        BufferedInputStream bis = new BufferedInputStream(new FileInputStream(serverFilePath));
        try {
            //输出流
            byte[] buff = new byte[2048];
            int readSize = 1;
            while (readSize > 0) {
                readSize = bis.read(buff, 0, buff.length);
                if (readSize > 0) {
                    bos.write(buff, 0, readSize);
                }
            }
        } finally {
            bis.close();
        }
    }
}
